==> knative-model-5.1.1-sources.jar: io/fabric8/knative/eventing/contrib/awssqs/v1alpha1/AwsSqsSourceFluent.java <==
package io.fabric8.knative.eventing.contrib.awssqs.v1alpha1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface AwsSqsSourceFluent<A extends AwsSqsSourceFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public AwsSqsSourceFluent.MetadataNested<A> withNewMetadata();
    public AwsSqsSourceFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public AwsSqsSourceFluent.MetadataNested<A> editMetadata();
    public AwsSqsSourceFluent.MetadataNested<A> editOrNewMetadata();
    public AwsSqsSourceFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public AwsSqsSourceSpec getSpec();
    public AwsSqsSourceSpec buildSpec();
    public A withSpec(AwsSqsSourceSpec spec);
    public Boolean hasSpec();
    public AwsSqsSourceFluent.SpecNested<A> withNewSpec();
    public AwsSqsSourceFluent.SpecNested<A> withNewSpecLike(AwsSqsSourceSpec item);
    public AwsSqsSourceFluent.SpecNested<A> editSpec();
    public AwsSqsSourceFluent.SpecNested<A> editOrNewSpec();
    public AwsSqsSourceFluent.SpecNested<A> editOrNewSpecLike(AwsSqsSourceSpec item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public AwsSqsSourceStatus getStatus();
    public AwsSqsSourceStatus buildStatus();
    public A withStatus(AwsSqsSourceStatus status);
    public Boolean hasStatus();
    public AwsSqsSourceFluent.StatusNested<A> withNewStatus();
    public AwsSqsSourceFluent.StatusNested<A> withNewStatusLike(AwsSqsSourceStatus item);
    public AwsSqsSourceFluent.StatusNested<A> editStatus();
    public AwsSqsSourceFluent.StatusNested<A> editOrNewStatus();
    public AwsSqsSourceFluent.StatusNested<A> editOrNewStatusLike(AwsSqsSourceStatus item);
    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<AwsSqsSourceFluent.MetadataNested<N>> {

            public N and();
            public N endMetadata();    }


    public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,AwsSqsSourceSpecFluent<AwsSqsSourceFluent.SpecNested<N>> {

            public N and();
            public N endSpec();    }


    public interface StatusNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,AwsSqsSourceStatusFluent<AwsSqsSourceFluent.StatusNested<N>> {

            public N and();
            public N endStatus();    }


}

==> knative-model-5.3.0-sources.jar: io/fabric8/knative/eventing/contrib/awssqs/v1alpha1/AwsSqsSourceFluent.java <==
package io.fabric8.knative.eventing.contrib.awssqs.v1alpha1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface AwsSqsSourceFluent<A extends AwsSqsSourceFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(int[] arg1,int arg2,int arg3);
    public A withNewApiVersion(char[] arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A withNewApiVersion(byte[] arg1,int arg2);
    public A withNewApiVersion(byte[] arg1);
    public A withNewApiVersion(char[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiVersion(String arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public AwsSqsSourceFluent.MetadataNested<A> withNewMetadata();
    public AwsSqsSourceFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public AwsSqsSourceFluent.MetadataNested<A> editMetadata();
    public AwsSqsSourceFluent.MetadataNested<A> editOrNewMetadata();
    public AwsSqsSourceFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public AwsSqsSourceSpec getSpec();
    public AwsSqsSourceSpec buildSpec();
    public A withSpec(AwsSqsSourceSpec spec);
    public Boolean hasSpec();
    public AwsSqsSourceFluent.SpecNested<A> withNewSpec();
    public AwsSqsSourceFluent.SpecNested<A> withNewSpecLike(AwsSqsSourceSpec item);
    public AwsSqsSourceFluent.SpecNested<A> editSpec();
    public AwsSqsSourceFluent.SpecNested<A> editOrNewSpec();
    public AwsSqsSourceFluent.SpecNested<A> editOrNewSpecLike(AwsSqsSourceSpec item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public AwsSqsSourceStatus getStatus();
    public AwsSqsSourceStatus buildStatus();
    public A withStatus(AwsSqsSourceStatus status);
    public Boolean hasStatus();
    public AwsSqsSourceFluent.StatusNested<A> withNewStatus();
    public AwsSqsSourceFluent.StatusNested<A> withNewStatusLike(AwsSqsSourceStatus item);
    public AwsSqsSourceFluent.StatusNested<A> editStatus();
    public AwsSqsSourceFluent.StatusNested<A> editOrNewStatus();
    public AwsSqsSourceFluent.StatusNested<A> editOrNewStatusLike(AwsSqsSourceStatus item);
    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<AwsSqsSourceFluent.MetadataNested<N>> {

            public N and();
            public N endMetadata();    }


    public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,AwsSqsSourceSpecFluent<AwsSqsSourceFluent.SpecNested<N>> {

            public N and();
            public N endSpec();    }


    public interface StatusNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,AwsSqsSourceStatusFluent<AwsSqsSourceFluent.StatusNested<N>> {

            public N and();
            public N endStatus();    }


}
